@@ -16,9 +16,9 @@
 from io import StringIO
 import os
 import sys
+from unittest import mock
 
 import ddt
-import mock
 from oslo_utils.fixture import uuidsentinel
 import six
 
@@ -105,7 +105,9 @@ class TestCreateVnfLcm(TestVnfLcm):
                 json={}, headers=self.header)
 
         sys.stdout = buffer = StringIO()
-        columns, data = (self.create_vnf_lcm.take_action(parsed_args))
+        actual_columns, data = (self.create_vnf_lcm.take_action(parsed_args))
+
+        headers, attributes = vnflcm._get_columns(json)
 
         expected_message = (
             'VNF Instance ' + json['id'] + ' is created and instantiation '
@@ -114,9 +116,9 @@ class TestCreateVnfLcm(TestVnfLcm):
             self.assertEqual(expected_message, buffer.getvalue().strip())
 
         self.assertItemsEqual(_get_columns_vnflcm(),
-                              columns)
-        self.assertItemsEqual(vnflcm_fakes.get_vnflcm_data(json),
-                              data)
+                              actual_columns)
+        self.assertListItemsEqual(vnflcm_fakes.get_vnflcm_data(
+            json, columns=attributes), data)
 
 
 class TestShowVnfLcm(TestVnfLcm):
@@ -145,6 +147,10 @@ class TestShowVnfLcm(TestVnfLcm):
         columns, data = (self.show_vnf_lcm.take_action(parsed_args))
         self.assertItemsEqual(_get_columns_vnflcm(action='show'),
                               columns)
+        headers, attributes = vnflcm._get_columns(vnf_instance, action='show')
+        self.assertListItemsEqual(
+            vnflcm_fakes.get_vnflcm_data(vnf_instance, columns=attributes),
+            data)
 
 
 class TestListVnfLcm(TestVnfLcm):
@@ -247,9 +253,9 @@ class TestInstantiateVnfLcm(TestVnfLcm):
                                self.instantiate_vnf_lcm.take_action,
                                parsed_args)
 
-        expected_msg = ("File %s does not exist or user does not have read "
-                        "privileges to it")
-        self.assertEqual(expected_msg % sample_param_file, ex.message)
+        expected_msg = ("Invalid input: File %s does not exist "
+                        "or user does not have read privileges to it")
+        self.assertEqual(expected_msg % sample_param_file, str(ex))
 
     @mock.patch("os.open")
     @mock.patch("os.access")
@@ -269,9 +275,8 @@ class TestInstantiateVnfLcm(TestVnfLcm):
         ex = self.assertRaises(exceptions.InvalidInput,
                                self.instantiate_vnf_lcm.take_action,
                                parsed_args)
-
         expected_msg = "Failed to load parameter file."
-        self.assertIn(expected_msg, ex.message)
+        self.assertIn(expected_msg, str(ex))
 
 
 @ddt.ddt
